## Future Roadmap

- Add performance optimizations
- OpenAPI Integration
- Pydantic Integration
- Implement Auto Const Requests
- Add ORM support, especially Prisma integration
- Improve Plugin Ecosystem
- Better Documentation
- Improve the Websockets
- Template Support
- Graphql integration with Strawberry
- Invest more time in the community around Robyn.
